#
# spec file for package python-fastbencode
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-fastbencode
Version:        0.3.2
Release:        1.1
Summary:        Implementation of the bencode serialization format
License:        GPL-2.0-or-later
URL:            https://github.com/breezy-team/fastbencode
Source:         https://github.com/breezy-team/fastbencode/archive/refs/tags/v%{version}.tar.gz#/fastbencode-%{version}.tar.gz
BuildRequires:  %{python_module Cython}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gcc
BuildRequires:  python-rpm-macros
%python_subpackages

%description
fastbencode is an implementation of the bencode serialization format
originally used by BitTorrent.

The package includes both a pure-Python version and an optional C extension
based on Cython. Both provide the same functionality, but the C extension
provides significantly better performance.

%prep
%autosetup -p1 -n fastbencode-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest_arch -v

%files %{python_files}
%doc README.md SECURITY.md
%license COPYING
%{python_sitearch}/fastbencode
%{python_sitearch}/fastbencode-%{version}*-info

%changelog
* Tue May 20 2025 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file.
* Mon May 19 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.3.2
  * Fix spelling errors
  * Upgrade artifact
  * Add missing dollar sign
  * Update copyright headers
  * Drop support for Python 3.8
  * Migrate to disperse.toml
  * Fix spelling errors
  * Use disperse action
  * Fix twine installation
  * Format
  * Enable auto-merge for dependabot PRs
  * Fix compatibility with Cython 3.1. Fixes #96
  * Extend workflows to run tests with C extension
  * Skip recursion tests with Python 3.12+
* Wed Jul 24 2024 Dirk Müller <dmueller@suse.com>
- update to 0.3.1:
  * Fix wheel build
- update to 0.3.0:
  * Use disperse action
  * Migrate to pyproject.toml
  * Enable ruff, pyupgrade
  * Fix compatibility with Python 3.12
  * Add python3.12 to the list of supported Python versions
* Thu Feb 16 2023 Dirk Müller <dmueller@suse.com>
- update to 0.2:
  * No upstream changelog available
* Mon Nov  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.1
  * Make C extension mandatory when built in cibuildwheel
  * Rely on standard infra for optionally building extension.
  * Don't install wheel explicitly
  * Fix uploading artifacts.
- Update to version 0.0.15
  * Publish wheels from the right directory.
- Update to version 0.0.14.
  * Depend on packaging for packaging.version.
  * Add pyproject.toml
  * Build wheels on pull request.
  * Build python wheels.
  * Migrate to setup.cfg.
  * Ship py.typed.
* Wed Oct 12 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 1.2.2
  Fix import error for Python 3.6+.
* Fri Jun 17 2022 Steve Kowalik <steven.kowalik@suse.com>
- Initial package for fastbencode 0.0.9.
